@@ -403,7 +403,7 @@ static void compare_report_html_footer(FILE *outstream)
   fprintf(outstream,
           "      <p class=\"footer\">\n"
           "        Generated by <a href=\"%s\">AEGeAn %s (%s %s)</a>.<br />\n"
-          "        Copyright © %s <a href=\"http://aegean.readthedocs.org/en/"
+          "        Copyright © %s <a href=\"http://aegean.readthedocs.io/en/"
           "latest/contrib.html\">AEGeAn authors</a>.<br />\n"
           "        See <a href=\"LICENSE\">LICENSE</a> for details."
           "      </p>\n", AGN_VERSION_LINK, AGN_SEMANTIC_VERSION,
@@ -712,7 +712,7 @@ static void compare_report_html_print_compclassfiles(AgnCompareReportHTML *rpt)
 {
   GtArray *compclassdata;
   GtUword i;
-  
+
   compclassdata = gt_hashmap_get(rpt->compclassdata, "perfect");
   if(gt_array_size(compclassdata) > 0)
   {
@@ -734,7 +734,7 @@ static void compare_report_html_print_compclassfiles(AgnCompareReportHTML *rpt)
     compare_report_html_seqfile_footer(outstream);
     fclose(outstream);
   }
-  
+
   compclassdata = gt_hashmap_get(rpt->compclassdata, "mislabeled");
   if(gt_array_size(compclassdata) > 0)
   {
@@ -757,7 +757,7 @@ static void compare_report_html_print_compclassfiles(AgnCompareReportHTML *rpt)
     compare_report_html_seqfile_footer(outstream);
     fclose(outstream);
   }
-  
+
   compclassdata = gt_hashmap_get(rpt->compclassdata, "cds");
   if(gt_array_size(compclassdata) > 0)
   {
@@ -779,7 +779,7 @@ static void compare_report_html_print_compclassfiles(AgnCompareReportHTML *rpt)
     compare_report_html_seqfile_footer(outstream);
     fclose(outstream);
   }
-  
+
   compclassdata = gt_hashmap_get(rpt->compclassdata, "exon");
   if(gt_array_size(compclassdata) > 0)
   {
@@ -801,7 +801,7 @@ static void compare_report_html_print_compclassfiles(AgnCompareReportHTML *rpt)
     compare_report_html_seqfile_footer(outstream);
     fclose(outstream);
   }
-  
+
   compclassdata = gt_hashmap_get(rpt->compclassdata, "utr");
   if(gt_array_size(compclassdata) > 0)
   {
@@ -823,7 +823,7 @@ static void compare_report_html_print_compclassfiles(AgnCompareReportHTML *rpt)
     compare_report_html_seqfile_footer(outstream);
     fclose(outstream);
   }
-  
+
   compclassdata = gt_hashmap_get(rpt->compclassdata, "nonmatch");
   if(gt_array_size(compclassdata) > 0)
   {
@@ -1127,7 +1127,7 @@ static void compare_report_html_summary_annot(AgnCompInfo *info,
           "      <h2>Gene loci <span class=\"tooltip\">[?]<span class=\"tooltip_text\">If a gene "
           "annotation overlaps with another gene annotation, those annotations are associated "
           "with the same gene locus. See <a target=\"_blank\" "
-          "href=\"http://aegean.readthedocs.org/en/refactor/loci.html\">"
+          "href=\"http://aegean.readthedocs.io/en/latest/loci.html\">"
           "this page</a> for a formal definition of a locus annotation.</span></span></h2>\n"
           "      <table class=\"table_normal\">\n"
           "        <tr><td>shared</td><td>%lu</td></tr>\n"
