@@ -311,6 +311,8 @@ static bool refine_locus_check_intron_genes(AgnLocusRefineStream *stream,
   GtStr *seqid = gt_genome_node_get_seqid(*gn1);
   AgnLocus *locus = agn_locus_new(seqid);
   agn_locus_add_feature(locus, fn1);
+  gt_feature_node_add_attribute((GtFeatureNode *)locus, "iLocus_type",
+                                "ciLocus");
   gt_genome_node_ref(*gn1);
   gt_array_add(iloci, locus);
 
@@ -408,11 +410,14 @@ static void locus_refine_stream_extend(AgnLocusRefineStream *stream,
   for(i = 0; i < numloci; i++)
   {
     GtGenomeNode **gn = gt_array_get(iloci, i);
+    GtFeatureNode *fn = gt_feature_node_cast(*gn);
     if(i == 0)
-      coding_status = agn_locus_num_mrnas(*gn) > 0;
+    {
+      coding_status = agn_typecheck_count(fn, agn_typecheck_cds) > 0;
+    }
     else
     {
-      bool test_status = agn_locus_num_mrnas(*gn) > 0;
+      bool test_status = agn_typecheck_count(fn, agn_typecheck_cds) > 0;
       same_coding_status = coding_status == test_status;
       if(!same_coding_status)
         break;
@@ -467,7 +472,10 @@ static void locus_refine_stream_extend(AgnLocusRefineStream *stream,
             fprintf(stream->ilenfile, "%s\t0\n", gt_str_get(seqid));
         }
       }
-      gt_feature_node_add_attribute(fn, "iLocus_type", typestr);
+      if(gt_feature_node_get_attribute(fn, "iLocus_type") == NULL)
+      {
+        gt_feature_node_add_attribute(fn, "iLocus_type", typestr);
+      }
     }
     if(numloci == 1)
     {
@@ -489,7 +497,7 @@ static void locus_refine_stream_extend(AgnLocusRefineStream *stream,
     GtFeatureNode *fn1 = gt_feature_node_cast(*gn1);
     GtFeatureNode *fn2 = gt_feature_node_cast(*gn2);
 
-    bool cds1 = agn_locus_num_mrnas(*gn1) > 0;
+    bool cds1 = agn_typecheck_count(fn1, agn_typecheck_cds) > 0;;
     if(cds1 == true)
     {
       gt_feature_node_add_attribute(fn1, "iLocus_type", "siLocus");
@@ -624,7 +632,10 @@ static void locus_refine_stream_extend(AgnLocusRefineStream *stream,
       {
         type = "ciLocus";
       }
-      gt_feature_node_add_attribute(fn, "iLocus_type", type);
+      if(gt_feature_node_get_attribute(fn, "iLocus_type") == NULL)
+      {
+        gt_feature_node_add_attribute(fn, "iLocus_type", type);
+      }
     }
   }
 
